@@ -1,5 +1,5 @@
-from PyObjCTools.TestSupport import *
 import IMServicePlugIn
+from PyObjCTools.TestSupport import TestCase
 import objc
 
 
@@ -16,7 +16,3 @@ class TestIMServicePlugInProtocols(TestCase):
         self.assertArgIsBOOL(
             TestIMServicePlugInProtocolsHelper.plugInDidLogOutWithError_reconnect_, 1
         )
-
-
-if __name__ == "__main__":
-    main()
